@@ -5,6 +5,7 @@ package Lingua::EN::Ngram;
 # Eric Lease Morgan <eric_morgan@infomotions.com>
 # September 12, 2010 - first investigations; based on Lingua::EN::Bigram
 # November  25, 2010 - added non-Latin characters; Happy Thanksgiving!
+# March     28, 2018 - removed lower-casing the text; why did I do lower case previously? 
 
 
 # include
@@ -12,7 +13,7 @@ use strict;
 use warnings;
 
 # define
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 sub new {
@@ -86,7 +87,7 @@ sub ngram {
 	$text =~ tr/a-zA-Zà-ƶÀ-Ƶ'()\-,.?!;:/\n/cs;
 	$text =~ s/([,.?!:;()\-])/\n$1\n/g;
 	$text =~ s/\n+/\n/g;
-	my @words = split /\n/, lc( $text );
+	my @words = split /\n/, $text;
 
 	my @ngrams = ();
 	my %count  = ();
@@ -124,7 +125,7 @@ sub tscore {
 	$text =~ tr/a-zA-Z'()\-,.?!;:/\n/cs;
 	$text =~ s/([,.?!:;()\-])/\n$1\n/g;
 	$text =~ s/\n+/\n/g;
-	my @words = split /\n/, lc( $text );
+	my @words = split /\n/, $text;
 
 	# count the words
 	my %word_count = ();
@@ -397,10 +398,14 @@ There are probably a number of ways the module can be improved:
 
 =over
 
-* September 12, 2010 (version 0.01) - initial release but an almost complete rewrite of Lingua::EN::Bigram
+* March 28, 2018 (version 0.03) - removed lower casing of letters and install ngrams script
 
 * November 25, 2010 (version 0.02) - added non-Latin characters
 
+* September 12, 2010 (version 0.01) - initial release but an almost complete rewrite of Lingua::EN::Bigram
+
+
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
